# KivyMD Extensions

<img align="left" width="256" src="https://github.com/kivymd/internal/raw/main/logo/kivymd_extensions.png"/>

KivyMD Extensions is a project to centralize community addons for KivyMD.
You can find all extensions under [@kivymd-extensions](https://github.com/kivymd-extensions)
organization.

Extensions are maintained by community members such as yourself.
If you want to create new extension,
generate a repository from [extension_template](https://github.com/kivymd-extensions/extension_template),
change all `extension_template` and `example_extension` to your new extension
name and edit code.
When you will be ready to publish extension,
create new issue at [kivymd-extensions/KivyMD_Extensions](https://github.com/kivymd-extensions/KivyMD_Extensions/issues)
with a link to your repository.
We will create repository under organization profile and push your code there.

## License

KivyMD Extensions is released under the terms of the [MIT License](https://github.com/kivymd-extensions/KivyMD_Extensions/blob/main/LICENSE), same as [KivyMD](https://github.com/kivymd/KivyMD/blob/master/LICENSE).
